Learn R Programming

cogmapr (version 0.9)

ConceptIndicIndiv: Concept Indicators of vertices by document

Description

Concept Indicators of vertices by document

Usage

ConceptIndicIndiv(project, sep = ">", coder = "qcoder")

Arguments

project

A QDA project, a list as generated by the ProjectCMap function.

sep

(==Depreciated, with RQDA project==) A character string (often a single character) that is used in RQDA in order to express the relationships between two variables. Default is "_" if codes used in RQDA are of the form : "x_y" (i.e. relationship from x to y), but it is possible to use ">", "->", "-->" or even "--->"

coder

A character string indicating the coding tool used for coding the QDA. The only tool supported now is 'qcoder'. Earlier version of cogmapr worked with "RQDA" project (no more maintened).

Value

A data frame of Concept Indicators by document (ICM)

Details

Concept Indicators of vertices by document

Examples

Run this code
# NOT RUN {
project_name <- "a_new_project"
main_path <- paste0(system.file("testdata", package = "cogmapr"), '/')
my.project <- ProjectCMap(main_path, project_name)

ConceptIndicIndiv(my.project)
# }

Run the code above in your browser using DataLab