Learn R Programming

cogmapr (version 0.9.5)

ConceptIndicSummary: Summary table on concept comparisons by indicator

Description

Summary table on concept comparisons by indicator

Usage

ConceptIndicSummary(project, units)

Value

A data frame

Arguments

project

A QDA project, a list as generated by the ProjectCMap function.

units

A string vector giving the names of the units (i.e. classes linked to documents) that will be include in the SCM. It is a second type of filter.

Details

This function produce a summary table based on concept comparisons by indicator.

Examples

Run this code
project_name <- "a_new_project"
main_path <- paste0(system.file("testdata", package = "cogmapr"), '/')
my.project <- ProjectCMap(main_path, project_name)

## More documents are needed for running this function
## ConceptIndicSummary(my.project, units = c("Belgium", "Québec"))

Run the code above in your browser using DataLab