A QDA project, a list as generated by the ProjectCMap function.
min.weight
A integer that will determine the minimum (>=) weight of relationships that will be taken into account. Relationships with a lower weight (<) will not be shown. Default is set to 1 (i.e. all relationships are shown).
weighted.icm
A boolean. If FALSE, the weight of the relationships in the ICM will be fixed to 1.